@@ -15,8 +15,11 @@ import signal
 import warnings
 
 from pickle import load, HIGHEST_PROTOCOL
-from billiard import util, process
+from billiard import util
+from billiard import process
+from billiard.five import int_types
 from .reduction import dump
+from .compat import _winapi as win32
 
 __all__ = ['Popen', 'assert_spawning', 'exit',
            'duplicate', 'close']
@@ -27,15 +30,6 @@ except NameError:
     class WindowsError(Exception):  # noqa
         pass
 
-try:
-    import _winapi as win32
-except ImportError:
-    try:
-        from _billiard import win32  # noqa
-    except ImportError:
-        if sys.platform == 'win32':
-            raise
-
 W_OLD_DJANGO_LAYOUT = """\
 Will add directory %r to path! This is necessary to accommodate \
 pre-Django 1.4 layouts using setup_environ.
@@ -92,6 +86,8 @@ if sys.platform != 'win32':
         _tls = thread._local()
 
         def __init__(self, process_obj):
+            # register reducers
+            from billiard import connection  # noqa
             _Django_old_layout_hack__save()
             sys.stdout.flush()
             sys.stderr.flush()
@@ -219,7 +215,7 @@ else:
         )
         if sys.version_info[0] < 3 or (
                 sys.version_info[0] == 3 and sys.version_info[1] < 3):
-            h.Detach()
+            h = h.Detach()
         return h
 
     #
@@ -248,13 +244,9 @@ else:
             hp, ht, pid, tid = _subprocess.CreateProcess(
                 _python_exe, cmd, None, None, 1, 0, None, None, None
             )
-            if sys.version_info[0] < 3 or (
-                    sys.version_info[0] == 3 and sys.version_info[1] < 3):
-                ht.Close()
-                rhandle.Close()
-            else:
-                close(ht)
-                close(rhandle)
+            close(ht) if isinstance(ht, int_types) else ht.Close()
+            (close(rhandle) if isinstance(rhandle, int_types)
+             else rhandle.Close())
 
             # set attributes of self
             self.pid = pid
